/*******************************************************************************
* File Name: ADC2.c
* Version 1.71
*
* Description:
*  This file provides the source code to the API for the Successive
*  approximation ADC Component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CyLib.h"
#include "ADC2.h"

#if(ADC2_DEFAULT_INTERNAL_CLK)
    #include "ADC2_theACLK.h"
#endif /* End ADC2_DEFAULT_INTERNAL_CLK */


/***************************************
* Forward function references
***************************************/
void ADC2_SetRef(int8 refMode);
void ADC2_CalcGain(uint8 resolution);


/***************************************
* Global data allocation
***************************************/
uint8 ADC2_initVar = 0u;
volatile int16 ADC2_offset;
volatile int16 ADC2_countsPerVolt;   /* Gain compensation */
volatile int16 ADC2_shift;
#if(CY_PSOC5_ES1)
    uint8 ADC2_resolution;
#endif /* End CY_PSOC5_ES1 */


/*******************************************************************************
* Function Name: ADC2_Start
********************************************************************************
*
* Summary:
*  Performs all required initialization for this component and enables the
*  power.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  The ADC2_initVar variable is used to indicate when/if initial 
*  configuration of this component has happened. The variable is initialized to 
*  zero and set to 1 the first time ADC_Start() is called. This allows for 
*  component Re-Start without re-initialization in all subsequent calls to the 
*  ADC2_Start() routine.
*  If re-initialization of the component is required the variable should be set 
*  to zero before call of ADC2_Start() routine, or the user may call 
*  ADC2_Init() and ADC2_Enable() as done in the 
*  ADC2_Start() routine.
*
*******************************************************************************/
void ADC2_Start(void)
{

    /* If not Initialized then initialize all required hardware and software */
    if(ADC2_initVar == 0u)
    {
        ADC2_Init();
        ADC2_initVar = 1u;
    }
    ADC2_Enable();
}


/*******************************************************************************
* Function Name: ADC2_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  ADC2_Start().
*
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global variables:
*  The ADC2_offset variable is initialized to 0.
*
*******************************************************************************/
void ADC2_Init(void)
{

    /* This is only valid if there is an internal clock */
    #if(ADC2_DEFAULT_INTERNAL_CLK)
        ADC2_theACLK_SetMode(CYCLK_DUTY);
    #endif /* End ADC2_DEFAULT_INTERNAL_CLK */

    /* Start and set interrupt vector */
    CyIntSetPriority(ADC2_INTC_NUMBER, ADC2_INTC_PRIOR_NUMBER);
    CyIntSetVector(ADC2_INTC_NUMBER, ADC2_ISR );

    /* Enable IRQ mode*/
    ADC2_SAR_CSR1_REG |= ADC2_SAR_IRQ_MASK_EN | ADC2_SAR_IRQ_MODE_EDGE;
    
    /*Set SAR ADC resolution ADC */
    ADC2_SetResolution(ADC2_DEFAULT_RESOLUTION);
    ADC2_offset = 0;
}


/*******************************************************************************
* Function Name: ADC2_Enable
********************************************************************************
*  
* Summary: 
*  Enables the reference, clock and power for SAR ADC.
*
* Parameters:  
*  None.
*
* Return: 
*  None.
*
*******************************************************************************/
void ADC2_Enable(void)
{
    uint8 tmpReg;
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

     /* Enable the SAR ADC block in Active Power Mode */
    ADC2_PWRMGR_SAR_REG |= ADC2_ACT_PWR_SAR_EN;

     /* Enable the SAR ADC in Standby Power Mode*/
    ADC2_STBY_PWRMGR_SAR_REG |= ADC2_STBY_PWR_SAR_EN;

    /* This is only valid if there is an internal clock */
    #if(ADC2_DEFAULT_INTERNAL_CLK)
        ADC2_PWRMGR_CLK_REG |= ADC2_ACT_PWR_CLK_EN;
        ADC2_STBY_PWRMGR_CLK_REG |= ADC2_STBY_PWR_CLK_EN;
    #endif /* End ADC2_DEFAULT_INTERNAL_CLK */

    /*Sets input range of the ADC*/
    #if(ADC2_DEFAULT_RANGE == ADC2__VSS_TO_VREF)
        ADC2_SetRef(ADC2_DEFAULT_RANGE);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VSSA_TO_VDDA)
        ADC2_SAR_CSR3_REG = ADC2_SAR_EN_RESVDA_EN;     /* Set bit for VDD/2 mode */
        ADC2_SetRef(ADC2__VSSA_TO_VDDA);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VSSA_TO_VDAC)
        ADC2_SetRef(ADC2_DEFAULT_RANGE);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VREF_DIFF)
        ADC2_SAR_CSR3_REG = ADC2_SAR_EN_CP_EN;         /* Enable charge pump*/
        ADC2_SetRef(ADC2_DEFAULT_RANGE);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDDA_DIFF)
        ADC2_SAR_CSR3_REG = ADC2_SAR_EN_CP_EN;         /* Enable charge pump*/
        ADC2_SetRef(ADC2__VSSA_TO_VDDA);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDDA_2_DIFF)
        ADC2_SAR_CSR3_REG = ADC2_SAR_EN_RESVDA_EN |    /* Set bit for VDD/2 mode*/
                                        ADC2_SAR_EN_CP_EN;         /* Enable charge pump*/
        ADC2_SetRef(ADC2__VSSA_TO_VDDA);
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDAC_DIFF)
        ADC2_SetRef(ADC2_DEFAULT_RANGE);
    #endif /* end ADC2_DEFAULT_RANGE */

    /* Set default power */
    tmpReg = (ADC2_DEFAULT_POWER << ADC2_SAR_POWER_SHIFT);
    /* Clear DAC value at beginning of sampling when internal reference used */
    #if(ADC2_DEFAULT_REFERENCE != ADC2__EXT_REF)
        tmpReg |= ADC2_SAR_HIZ_CLEAR;
    #endif /* End ADC2_DEFAULT_REFERENCE != ADC2__EXT_REF */    
    /*Set Convertion mode */
    #if(ADC2_DEFAULT_CONV_MODE == ADC2__TRIGGERED)      /* If triggered mode */
        tmpReg |= ADC2_SAR_MX_SOF_UDB |          /* source: UDB */
                  ADC2_SAR_SOF_MODE_EDGE;        /* Set edge-sensitive sof source */
    #endif /* ADC2_DEFAULT_CONV_MODE */
    ADC2_SAR_CSR0_REG = tmpReg;

    /* Enable clock for SAR ADC*/
    ADC2_SAR_CLK_REG |= ADC2_SAR_MX_CLK_EN;
   
    #if(CY_PSOC5_ES1)
        /* Software Reset */
        ADC2_SAR_CSR0_REG |= ADC2_SAR_RESET_SOFT_ACTIVE;
        CyDelayUs(2); /* 2us delay is required for the lowest 1Mhz clock connected to SAR */
        ADC2_SAR_CSR0_REG &= ~ADC2_SAR_RESET_SOFT_ACTIVE;
    #endif /* End CY_PSOC5_ES1 */

    /* Clear a pending interrupt */
    CyIntClearPending(ADC2_INTC_NUMBER);
    
    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ADC2_SetRef
********************************************************************************
*
* Summary:
*   Sets reference for ADC
*
* Parameters:
*  refMode: Reference configuration.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC2_SetRef(int8 refMode)
{
    uint8 tmpReg;
    if(refMode == ADC2__VSSA_TO_VDDA)
    {
        #if(ADC2_DEFAULT_REFERENCE == ADC2__INT_REF_NOT_BYPASSED)
            tmpReg = ADC2_SAR_REF_S3_LSB_EN | ADC2_SAR_REF_S4_LSB_EN;
            ADC2_SAR_CSR3_REG |= ADC2_SAR_EN_BUF_VREF_EN; /* Enable Int Ref Amp*/
        #elif(ADC2_DEFAULT_REFERENCE == ADC2__INT_REF_BYPASS)
            tmpReg = ADC2_SAR_REF_S2_LSB_EN | ADC2_SAR_REF_S3_LSB_EN | 
                     ADC2_SAR_REF_S4_LSB_EN;
            ADC2_SAR_CSR3_REG |= ADC2_SAR_EN_BUF_VREF_EN; /* Enable Int Ref Amp*/
        #elif(ADC2_DEFAULT_REFERENCE == ADC2__EXT_REF)
            tmpReg = ADC2_SAR_REF_S2_LSB_EN;
            ADC2_SAR_CSR3_REG &= ~ADC2_SAR_EN_BUF_VREF_EN; /* Disable Int Ref Amp*/
        #endif /*  End ADC2_DEFAULT_REFERENCE */
    }
    else
    {
        #if(ADC2_DEFAULT_REFERENCE == ADC2__INT_REF_NOT_BYPASSED)
            tmpReg = ADC2_SAR_REF_S3_LSB_EN | ADC2_SAR_REF_S4_LSB_EN;
            ADC2_SAR_CSR3_REG |= ADC2_SAR_EN_BUF_VREF_EN; /* Enable Int Ref Amp*/
        #elif(ADC2_DEFAULT_REFERENCE == ADC2__INT_REF_BYPASS)
            tmpReg = ADC2_SAR_REF_S2_LSB_EN | ADC2_SAR_REF_S3_LSB_EN | 
                     ADC2_SAR_REF_S4_LSB_EN;
            ADC2_SAR_CSR3_REG |= ADC2_SAR_EN_BUF_VREF_EN; /* Enable Int Ref Amp*/
        #elif(ADC2_DEFAULT_REFERENCE == ADC2__EXT_REF)
            tmpReg = ADC2_SAR_REF_S2_LSB_EN;
            ADC2_SAR_CSR3_REG &= ~ADC2_SAR_EN_BUF_VREF_EN; /* Disable Int Ref Amp*/
        #endif /*  End ADC2_DEFAULT_REFERENCE */
    }
    ADC2_SAR_CSR6_REG = tmpReg;
    ADC2_SAR_CSR7_REG = ADC2_SAR_REF_S_MSB_DIS;
}


/*******************************************************************************
* Function Name: ADC2_Stop
********************************************************************************
*
* Summary:
*  Stops convertion and reduce the power to the minimum.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC2_Stop(void)
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    /* Stop all conversions */
    ADC2_SAR_CSR0_REG &= ~ADC2_SAR_SOF_START_CONV;
    
    #if(CY_PSOC5_ES1)
        /* Leave the SAR block powered and reduce the power to the minimum */
        ADC2_SAR_CSR0_REG |= ADC2_ICONT_LV_3;
        /* Disable reference buffer and reduce the reference power to the minimum */
        ADC2_SAR_CSR3_REG = ADC2_SAR_PWR_CTRL_VREF_DIV_BY4;    
    #else    
        /* Disable the SAR ADC block in Active Power Mode */
        ADC2_PWRMGR_SAR_REG &= ~ADC2_ACT_PWR_SAR_EN;
        /* Disable the SAR ADC in Standby Power Mode */
        ADC2_STBY_PWRMGR_SAR_REG &= ~ADC2_STBY_PWR_SAR_EN;
        /* Disable power for reference buffer and charge pump*/
        ADC2_SAR_CSR3_REG = ADC2_SAR_EN_BUF_VREF_DIS;    
    #endif /* End CY_PSOC5_ES1 */
    

    /* This is only valid if there is an internal clock */
    #if(ADC2_DEFAULT_INTERNAL_CLK)
        ADC2_PWRMGR_CLK_REG &= ~ADC2_ACT_PWR_CLK_EN;
        ADC2_STBY_PWRMGR_CLK_REG &= ~ADC2_STBY_PWR_CLK_EN;
    #endif /* End ADC2_DEFAULT_INTERNAL_CLK */

    CyExitCriticalSection(enableInterrupts);
    
}


/*******************************************************************************
* Function Name: ADC2_IRQ_Enable
********************************************************************************
* Summary:
*  Enables the interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC2_IRQ_Enable(void)
{
    /* Enable the general interrupt. */
    CyIntEnable(ADC2_INTC_NUMBER);
}


/*******************************************************************************
* Function Name: ADC2_IRQ_Disable
********************************************************************************
*
* Summary:
*  Disables the Interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC2_IRQ_Disable(void)
{
    /* Disable the general interrupt. */
    CyIntDisable(ADC2_INTC_NUMBER);
}


/*******************************************************************************
* Function Name: ADC2_SetPower
********************************************************************************
*
* Summary:
*  Sets the Power mode.
*
* Parameters:
*  power:  Power setting for ADC
*  0 ->    Normal
*  1 ->    Half power
*  2 ->    1/3rd power
*  3 ->    Quarter power.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC2_SetPower(uint8 power)
{
    uint8 tmpReg;

    /* mask off invalid power settings */
    power &= ADC2_SAR_API_POWER_MASK;

    /* Set Power parameter  */
    tmpReg = ADC2_SAR_CSR0_REG & ~ADC2_SAR_POWER_MASK;
    tmpReg |= (power << ADC2_SAR_POWER_SHIFT);
    ADC2_SAR_CSR0_REG = tmpReg;
}


/*******************************************************************************
* Function Name: ADC2_SetResolution
********************************************************************************
*
* Summary:
*  Sets the Relution of the SAR.
*  This function does not affect the actual conversion with PSoC5 ES1 silicon.
*
* Parameters:
*  resolution:
*  12 ->    RES12
*  10 ->    RES10
*  8  ->    RES8
*
* Return:
*  None.
*
* Side Effects:
*  The ADC resolution cannot be changed during a conversion cycle. The recommended
*  best practice is to stop conversions with ADC_StopConvert(), change the 
*  resolution, then restart the conversions with ADC_StartConvert().
*  If you decide not to stop conversions before calling this API, you should use 
*  ADC_IsEndConversion() to wait until conversion is complete before changing the 
*  resolution.
*  If you call ADC_SetResolution() during a conversion, the resolution will not 
*  be changed until the current conversion is complete. Data will not be available 
*  in the new resolution for another 6 + “New Resolution(in bits)” clock cycles. 
*  You may need add a delay of this number of clock cycles after ADC_SetResolution()
*  is called before data is valid again.
*  Affects ADC_CountsTo_Volts(), ADC_CountsTo_mVolts(), and ADC_CountsTo_uVolts() 
*  by calculating the correct conversion between ADC counts and the applied input 
*  voltage. Calculation depends on resolution, input range, and voltage reference.
*
*******************************************************************************/
void ADC2_SetResolution(uint8 resolution)
{
    uint8 tmpReg;

    /* remember resolution for the GetResult APIs */
    #if(CY_PSOC5_ES1)
        ADC2_resolution = resolution;
    #endif /* End CY_PSOC5_ES1 */
    
    /* Set SAR ADC resolution */
    switch (resolution)
    {
        case ADC2__BITS_12:
            tmpReg = ADC2_SAR_RESOLUTION_12BIT;
            break;
        case ADC2__BITS_10:
            /* Use 12bits for PSoC5 production silicon and shift the 
            *  results for lower resolution in GetResult16() API 
            */
            #if(CY_PSOC5_ES1)
                tmpReg = ADC2_SAR_RESOLUTION_12BIT;
            #else    
                tmpReg = ADC2_SAR_RESOLUTION_10BIT;
            #endif /* End CY_PSOC5_ES1 */
            break;
        case ADC2__BITS_8:
            #if(CY_PSOC5_ES1)
                tmpReg = ADC2_SAR_RESOLUTION_12BIT;
            #else    
                tmpReg = ADC2_SAR_RESOLUTION_8BIT;
            #endif /* End CY_PSOC5_ES1 */
            break;
        default:
            tmpReg = ADC2_SAR_RESOLUTION_12BIT;
            break;
    }
    
     tmpReg |= ADC2_SAR_SAMPLE_WIDTH;   /* 18 conversion cycles @ 12bits + 1 gap*/
    ADC2_SAR_CSR2_REG = tmpReg;
    
     /* Calculate gain for convert counts to volts */
    ADC2_CalcGain(resolution);
}


/*******************************************************************************
* Function Name: ADC2_StartConvert
********************************************************************************
*
* Summary:
*  Starts ADC conversion using the given mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Forces the ADC to initiate a conversion. In Free Running mode, the ADC will 
*  run continuously. In a triggered mode the function also acts as a software
*  version of the SOC. Here every conversion has to be triggered by the routine. 
*  This writes into the SOC bit in SAR_CTRL reg.
*
* Side Effects:
*  In a triggered mode the function switches source for SOF from the external 
*  pin to the internal SOF generation. Application should not call StartConvert
*  if external source used for SOF.
*******************************************************************************/
void ADC2_StartConvert(void)
{
    #if(ADC2_DEFAULT_CONV_MODE == ADC2__TRIGGERED)   /* If triggered mode */
        ADC2_SAR_CSR0_REG &= ~ADC2_SAR_MX_SOF_UDB;   /* source: SOF bit */
    #endif /* End ADC2_DEFAULT_CONV_MODE */
    
    /* Start the conversion */
    ADC2_SAR_CSR0_REG |= ADC2_SAR_SOF_START_CONV;
}


/*******************************************************************************
* Function Name: ADC2_StopConvert
********************************************************************************
*
* Summary:
*  Stops ADC conversion using the given mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Stops ADC conversion in Free Running mode. 
*  This writes into the SOC bit in SAR_CTRL reg.
*
* Side Effects:
*  In a triggered mode the function set a software version of the SOC to low level
*  and switch SOF source to hardware SOF input.
*  
*******************************************************************************/
void ADC2_StopConvert(void)
{
    /* Stop all conversions */
    ADC2_SAR_CSR0_REG &= ~ADC2_SAR_SOF_START_CONV;

    #if(ADC2_DEFAULT_CONV_MODE == ADC2__TRIGGERED)   /* If triggered mode */
        /* Return source to UDB for hardware SOF signal */
        ADC2_SAR_CSR0_REG |= ADC2_SAR_MX_SOF_UDB;    /* source: UDB */
    #endif /* End ADC2_DEFAULT_CONV_MODE */
    
}


/*******************************************************************************
* Function Name: ADC2_IsEndConversion
********************************************************************************
*
* Summary:
*  Queries the ADC to see if conversion is complete
*
* Parameters:
*  retMode:  Wait mode,
*   0 if return with answer imediately.
*   1 if wait until conversion is complete, then return.
*
* Return:
*  (uint8)  0 =>  Conversion not complete.
*           1 =>  Conversion complete.
*
*******************************************************************************/
uint8 ADC2_IsEndConversion(uint8 retMode)
{
    uint8 status;

    do
    {
        status = ADC2_SAR_CSR1_REG & ADC2_SAR_EOF_1;
    } while ((status != ADC2_SAR_EOF_1) && (retMode == ADC2_WAIT_FOR_RESULT));
    /* If convertion complete, wait until EOF bit released */
    if(status == ADC2_SAR_EOF_1)
    {
        /* wait one ADC clock to let the EOC status bit release */
        CyDelayUs(1);
        /* Do the unconditional read operation of the CSR1 register to make sure the EOC bit has been cleared */
        CY_GET_REG8(ADC2_SAR_CSR1_PTR);
    }    

    return(status);
}


/*******************************************************************************
* Function Name: ADC2_GetResult8
********************************************************************************
*
* Summary:
*  Returns an 8-bit result or the LSB of the last conversion. 
*  ADC2_IsEndConversion() should be called to verify that the data 
*   sample is ready 
*
* Parameters:
*  None.
*
* Return:
*  ADC result.
*
* Global Variables:
*  ADC2_shift - used to convert the ADC counts to the 2's 
*  compliment form.
*  ADC2_resolution – used to shift the results for lower 
*   resolution.
*
*******************************************************************************/
int8 ADC2_GetResult8( void )
{
    
    #if(CY_PSOC5_ES1)

        int16 res;

        res = CY_GET_REG16(ADC2_SAR_WRK0_PTR) - ADC2_shift;
        
        /* Use 12bits for PSoC5 production silicon and shift the results for lower resolution in this API */
        if(ADC2_resolution == ADC2__BITS_10)
        {
            res >>= 2u;
        }
        else if(ADC2_resolution == ADC2__BITS_8)
        {
            res >>= 4u;
        }
        else    /* Do not shift for 12 bits */
        {
        }
        return( (int8)res );
        
    #else
        return( ADC2_SAR_WRK0_REG - (int8)ADC2_shift);
    #endif /* End CY_PSOC5_ES1 */

}


/*******************************************************************************
* Function Name: ADC2_GetResult16
********************************************************************************
*
* Summary:
*  Gets the data available in the SAR DATA registers.
*  ADC2_IsEndConversion() should be called to verify that the data 
*   sample is ready 
*
* Parameters:
*  None.
*
* Return:
*  ADC result. WORD value which has the converted 12bits. In the differential 
*  input mode the SAR ADC outputs digitally converted data in binary offset 
*  scheme, this function converts the data into 2's compliment form. 
*
* Global Variables:
*  ADC2_shift - used to convert the ADC counts to the 2's 
*  compliment form.
*  ADC2_resolution – used to shift the results for lower 
*   resolution.
*
*******************************************************************************/
int16 ADC2_GetResult16( void )
{
    int16 res;
    
    res = CY_GET_REG16(ADC2_SAR_WRK0_PTR) - ADC2_shift;

    #if(CY_PSOC5_ES1)
        /* Use 12bits for PSoC5 production silicon and shift the results for lower resolution in this API */
        if(ADC2_resolution == ADC2__BITS_10)
        {
            res >>= 2u;
        }
        else if(ADC2_resolution == ADC2__BITS_8)
        {
            res >>= 4u;
        }
        else    /* Do not shift for 12 bits */
        {
        }
    #endif /* End CY_PSOC5_ES1 */

    return( res );
}


/*******************************************************************************
* Function Name: ADC2_SetOffset
********************************************************************************
*
* Summary:
*  This function sets the offset for voltage readings.
*
* Parameters:
*  int16: Offset in counts
*
* Return:
*  None.
*
* Global Variables:
*  The ADC2_offset variable modified. This variable is used for 
*  offset calibration purpose. 
*  Affects the ADC2_CountsTo_Volts, 
*  ADC2_CountsTo_mVolts, ADC2_CountsTo_uVolts functions 
*  by subtracting the given offset. 
*
*******************************************************************************/
void ADC2_SetOffset(int16 offset)
{
    ADC2_offset = offset;
}


/*******************************************************************************
* Function Name: ADC2_CalcGain
********************************************************************************
*
* Summary:
*  This function calculates the ADC gain in counts per volt.
*
* Parameters:
*  uint8: resolution
*
* Return:
*  None.
*
* Global Variables:
*  ADC2_shift variable initialized. This variable is used to 
*  convert the ADC counts to the 2's compliment form. 
*  ADC2_countsPerVolt variable initialized. This variable is used 
*  for gain calibration purpose. 
*
*******************************************************************************/
void ADC2_CalcGain( uint8 resolution )
{
    uint32 counts = ADC2_SAR_WRK_MAX;       /*default 12 bits*/
    uint16 diff_zero = ADC2_SAR_DIFF_SHIFT;
    
    if(resolution == ADC2__BITS_10)
    {
        counts >>= 2u;
        /* Use 12bits for PSoC5 production silicon */
        #if(CY_PSOC5_ES2)
            diff_zero >>= 2u;
        #else  /* To avoid the warning */  
            diff_zero = diff_zero;
        #endif /* End CY_PSOC5_ES2 */
    }
    if(resolution == ADC2__BITS_8)
    {
        counts >>= 4u;
        /* Use 12bits for PSoC5 production silicon */
        #if(CY_PSOC5_ES2)
            diff_zero >>= 4u;
        #else  /* To avoid the warning */  
            diff_zero = diff_zero;
        #endif /* End CY_PSOC5_ES2 */
    }
    counts *= 1000u; /* To avoid float point arithmetic*/
    ADC2_countsPerVolt = counts / ADC2_DEFAULT_REF_VOLTAGE_MV / 2;

    #if(ADC2_DEFAULT_RANGE == ADC2__VSS_TO_VREF)
        ADC2_shift = 0;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VSSA_TO_VDDA)
        ADC2_shift = 0;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VSSA_TO_VDAC)
        ADC2_shift = 0;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VREF_DIFF)
        ADC2_shift = diff_zero;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDDA_DIFF)
        ADC2_shift = diff_zero;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDDA_2_DIFF)
        ADC2_shift = diff_zero;
    #elif(ADC2_DEFAULT_RANGE == ADC2__VNEG_VDAC_DIFF)
        ADC2_shift = diff_zero;
    #endif /* End ADC2_DEFAULT_RANGE */    
}


/*******************************************************************************
* Function Name: ADC2_SetGain
********************************************************************************
*
* Summary:
*  This function sets the ADC gain in counts per volt.
*
* Parameters:
*  int16  adcGain  counts per volt
*
* Return:
*  None.
*
* Global Variables:
*  ADC2_countsPerVolt variable modified. This variable is used 
*  for gain calibration purpose. 
*
*******************************************************************************/
void ADC2_SetGain(int16 adcGain)
{
    ADC2_countsPerVolt = adcGain;
}


/*******************************************************************************
* Function Name: ADC2_CountsTo_mVolts
********************************************************************************
*
* Summary:
*  This function converts ADC counts to mVolts
*
* Parameters:
*  int16  adcCounts   Reading from ADC.
*
* Return:
*  int16  Result in mVolts
*
* Global Variables:
*  ADC2_offset variable used.
*  ADC2_countsPerVolt variable used.
*
*******************************************************************************/
int16 ADC2_CountsTo_mVolts(int16 adcCounts)
{

    int16 mVolts;

    /* Subtract ADC offset */
    adcCounts -= ADC2_offset;

    mVolts = ( (int32)adcCounts * 1000 ) / ADC2_countsPerVolt ;

    return( mVolts );
}


/*******************************************************************************
* Function Name: ADC2_CountsTo_uVolts
********************************************************************************
*
* Summary:
*  This function converts ADC counts to micro Volts
*
* Parameters:
*  int16  adcCounts   Reading from ADC.
*
* Return:
*  int32  Result in micro Volts
*
* Global Variables:
*  ADC2_offset variable used.
*  ADC2_countsPerVolt variable used.
*
*******************************************************************************/
int32 ADC2_CountsTo_uVolts(int16 adcCounts)
{

    int32 uVolts;

    /* Subtract ADC offset */
    adcCounts -= ADC2_offset;
    /* To convert adcCounts to microVolts it is required to be multiplied
    *  on 1 million. It is multiplied on 500000 and later on 2 to 
    *  to avoid 32bit arithmetic overflows. 
    */
    uVolts = (( (int32)adcCounts * 500000 ) / ADC2_countsPerVolt) * 2;

    return( uVolts );
}


/*******************************************************************************
* Function Name: ADC2_CountsTo_Volts
********************************************************************************
*
* Summary:
*  This function converts ADC counts to Volts
*
* Parameters:
*  int16  adcCounts   Reading from ADC.
*
* Return:
*  float  Result in mVolts
*
* Global Variables:
*  ADC2_offset variable used.
*  ADC2_countsPerVolt variable used.
*
*******************************************************************************/
float ADC2_CountsTo_Volts(int16 adcCounts)
{
    float volts;

    /* Subtract ADC offset */
    adcCounts -= ADC2_offset;

    volts = (float)adcCounts / (float)ADC2_countsPerVolt;   

    return( volts );
}


/* [] END OF FILE */
