/*******************************************************************************
* File Name: Comp_Timer_PM.c
* Version 2.50
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "Comp_Timer.h"
static Comp_Timer_backupStruct Comp_Timer_backup;


/*******************************************************************************
* Function Name: Comp_Timer_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Comp_Timer_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void Comp_Timer_SaveConfig(void) 
{
    #if (!Comp_Timer_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            Comp_Timer_backup.TimerUdb = Comp_Timer_ReadCounter();
            Comp_Timer_backup.TimerPeriod = Comp_Timer_ReadPeriod();
            Comp_Timer_backup.InterruptMaskValue = Comp_Timer_STATUS_MASK;
            #if (Comp_Timer_UsingHWCaptureCounter)
                Comp_Timer_backup.TimerCaptureCounter = Comp_Timer_ReadCaptureCount();
            #endif /* Backup the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Backup the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            Comp_Timer_backup.TimerUdb = Comp_Timer_ReadCounter();
            Comp_Timer_backup.InterruptMaskValue = Comp_Timer_STATUS_MASK;
            #if (Comp_Timer_UsingHWCaptureCounter)
                Comp_Timer_backup.TimerCaptureCounter = Comp_Timer_ReadCaptureCount();
            #endif /* Back Up capture counter register  */
        #endif /* Backup non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!Comp_Timer_ControlRegRemoved)
            Comp_Timer_backup.TimerControlRegister = Comp_Timer_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: Comp_Timer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Comp_Timer_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Comp_Timer_RestoreConfig(void) 
{   
    #if (!Comp_Timer_UsingFixedFunction)
        /* Restore the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            /* Interrupt State Backup for Critical Region*/
            uint8 Comp_Timer_interruptState;

            Comp_Timer_WriteCounter(Comp_Timer_backup.TimerUdb);
            Comp_Timer_WritePeriod(Comp_Timer_backup.TimerPeriod);
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Comp_Timer_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            Comp_Timer_STATUS_AUX_CTRL |= Comp_Timer_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(Comp_Timer_interruptState);
            Comp_Timer_STATUS_MASK =Comp_Timer_backup.InterruptMaskValue;
            #if (Comp_Timer_UsingHWCaptureCounter)
                Comp_Timer_SetCaptureCount(Comp_Timer_backup.TimerCaptureCounter);
            #endif /* Restore the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Restore the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            Comp_Timer_WriteCounter(Comp_Timer_backup.TimerUdb);
            Comp_Timer_STATUS_MASK =Comp_Timer_backup.InterruptMaskValue;
            #if (Comp_Timer_UsingHWCaptureCounter)
                Comp_Timer_SetCaptureCount(Comp_Timer_backup.TimerCaptureCounter);
            #endif /* Restore Capture counter register*/
        #endif /* Restore up non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!Comp_Timer_ControlRegRemoved)
            Comp_Timer_WriteControlRegister(Comp_Timer_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: Comp_Timer_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Comp_Timer_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void Comp_Timer_Sleep(void) 
{
    #if(!Comp_Timer_ControlRegRemoved)
        /* Save Counter's enable state */
        if(Comp_Timer_CTRL_ENABLE == (Comp_Timer_CONTROL & Comp_Timer_CTRL_ENABLE))
        {
            /* Timer is enabled */
            Comp_Timer_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            Comp_Timer_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    Comp_Timer_Stop();
    Comp_Timer_SaveConfig();
}


/*******************************************************************************
* Function Name: Comp_Timer_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Comp_Timer_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Comp_Timer_Wakeup(void) 
{
    Comp_Timer_RestoreConfig();
    #if(!Comp_Timer_ControlRegRemoved)
        if(Comp_Timer_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                Comp_Timer_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
