/*******************************************************************************
* File Name: RE_Counter1_PM.c  
* Version 2.20
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "RE_Counter1.h"

static RE_Counter1_backupStruct RE_Counter1_backup;


/*******************************************************************************
* Function Name: RE_Counter1_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter1_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void RE_Counter1_SaveConfig(void) 
{
    #if (!RE_Counter1_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC5A */
        #if (CY_PSOC5A)
            RE_Counter1_backup.CounterUdb = RE_Counter1_ReadCounter();
            RE_Counter1_backup.CounterPeriod = RE_Counter1_ReadPeriod();
            RE_Counter1_backup.CompareValue = RE_Counter1_ReadCompare();
            RE_Counter1_backup.InterruptMaskValue = RE_Counter1_STATUS_MASK;
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            RE_Counter1_backup.CounterUdb = RE_Counter1_ReadCounter();
            RE_Counter1_backup.InterruptMaskValue = RE_Counter1_STATUS_MASK;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(!RE_Counter1_ControlRegRemoved)
            RE_Counter1_backup.CounterControlRegister = RE_Counter1_ReadControlRegister();
        #endif /* (!RE_Counter1_ControlRegRemoved) */
    #endif /* (!RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter1_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void RE_Counter1_RestoreConfig(void) 
{      
    #if (!RE_Counter1_UsingFixedFunction)     
        /* Restore the UDB non-rentention registers for PSoC5A */
        #if (CY_PSOC5A)
            /* Interrupt State Backup for Critical Region*/
            uint8 RE_Counter1_interruptState;
        
            RE_Counter1_WriteCounter(RE_Counter1_backup.CounterUdb);
            RE_Counter1_WritePeriod(RE_Counter1_backup.CounterPeriod);
            RE_Counter1_WriteCompare(RE_Counter1_backup.CompareValue);
            /* Enter Critical Region*/
            RE_Counter1_interruptState = CyEnterCriticalSection();
        
            RE_Counter1_STATUS_AUX_CTRL |= RE_Counter1_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(RE_Counter1_interruptState);
            RE_Counter1_STATUS_MASK = RE_Counter1_backup.InterruptMaskValue;
        #endif  /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            RE_Counter1_WriteCounter(RE_Counter1_backup.CounterUdb);
            RE_Counter1_STATUS_MASK = RE_Counter1_backup.InterruptMaskValue;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(!RE_Counter1_ControlRegRemoved)
            RE_Counter1_WriteControlRegister(RE_Counter1_backup.CounterControlRegister);
        #endif /* (!RE_Counter1_ControlRegRemoved) */
    #endif /* (!RE_Counter1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: RE_Counter1_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter1_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void RE_Counter1_Sleep(void) 
{
    #if(!RE_Counter1_ControlRegRemoved)
        /* Save Counter's enable state */
        if(RE_Counter1_CTRL_ENABLE == (RE_Counter1_CONTROL & RE_Counter1_CTRL_ENABLE))
        {
            /* Counter is enabled */
            RE_Counter1_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            RE_Counter1_backup.CounterEnableState = 0u;
        }
    #endif /* (!RE_Counter1_ControlRegRemoved) */
    RE_Counter1_Stop();
    RE_Counter1_SaveConfig();
}


/*******************************************************************************
* Function Name: RE_Counter1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter1_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void RE_Counter1_Wakeup(void) 
{
    RE_Counter1_RestoreConfig();
    #if(!RE_Counter1_ControlRegRemoved)
        if(RE_Counter1_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            RE_Counter1_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!RE_Counter1_ControlRegRemoved) */
    
}


/* [] END OF FILE */
