/*******************************************************************************
* File Name: RE_Counter_PM.c  
* Version 2.10
*
*  Description:
*     This file provides the power management source code to API for the
*     Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "RE_Counter.h"

static RE_Counter_backupStruct RE_Counter_backup;

/*******************************************************************************
* Function Name: RE_Counter_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*    No
*
*******************************************************************************/
void RE_Counter_SaveConfig(void)
{
    #if (!RE_Counter_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (RE_Counter_PSOC3_ES2 || RE_Counter_PSOC5_ES1)
            RE_Counter_backup.CounterUdb = RE_Counter_ReadCounter();
            RE_Counter_backup.CounterPeriod = RE_Counter_ReadPeriod();
            RE_Counter_backup.CompareValue = RE_Counter_ReadCompare();
            RE_Counter_backup.InterruptMaskValue = RE_Counter_STATUS_MASK;
        #endif
        
        #if (RE_Counter_PSOC3_ES3 || RE_Counter_PSOC5_ES2)
            RE_Counter_backup.CounterUdb = RE_Counter_ReadCounter();
            RE_Counter_backup.InterruptMaskValue = RE_Counter_STATUS_MASK;
        #endif
        
        #if(!RE_Counter_ControlRegRemoved)
            RE_Counter_backup.CounterControlRegister = RE_Counter_ReadControlRegister();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: RE_Counter_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void RE_Counter_RestoreConfig(void) 
{      
    #if (!RE_Counter_UsingFixedFunction)     
        /* Restore the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (RE_Counter_PSOC3_ES2 || RE_Counter_PSOC5_ES1)
            /* Interrupt State Backup for Critical Region*/
            uint8 RE_Counter_interruptState;
        
            RE_Counter_WriteCounter(RE_Counter_backup.CounterUdb);
            RE_Counter_WritePeriod(RE_Counter_backup.CounterPeriod);
            RE_Counter_WriteCompare(RE_Counter_backup.CompareValue);
            /* Enter Critical Region*/
            RE_Counter_interruptState = CyEnterCriticalSection();
        
            RE_Counter_STATUS_AUX_CTRL |= RE_Counter_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(RE_Counter_interruptState);
            RE_Counter_STATUS_MASK = RE_Counter_backup.InterruptMaskValue;
        #endif
        
        #if (RE_Counter_PSOC3_ES3 || RE_Counter_PSOC5_ES2)
            RE_Counter_WriteCounter(RE_Counter_backup.CounterUdb);
            RE_Counter_STATUS_MASK = RE_Counter_backup.InterruptMaskValue;
        #endif
        
        #if(!RE_Counter_ControlRegRemoved)
            RE_Counter_WriteControlRegister(RE_Counter_backup.CounterControlRegister);
        #endif
    #endif
}


/*******************************************************************************
* Function Name: RE_Counter_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void RE_Counter_Sleep(void)
{
    #if(!RE_Counter_ControlRegRemoved)
        /* Save Counter's enable state */
        if(RE_Counter_CTRL_ENABLE == (RE_Counter_CONTROL & RE_Counter_CTRL_ENABLE))
        {
            /* Counter is enabled */
            RE_Counter_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            RE_Counter_backup.CounterEnableState = 0u;
        }
    #endif
    RE_Counter_Stop();
    RE_Counter_SaveConfig();
}


/*******************************************************************************
* Function Name: RE_Counter_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RE_Counter_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void RE_Counter_Wakeup(void) 
{
    RE_Counter_RestoreConfig();
    #if(!RE_Counter_ControlRegRemoved)
        if(RE_Counter_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            RE_Counter_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif
    
}


/* [] END OF FILE */
