/*******************************************************************************
* File Name: RotaryEncoder_1_Counter_PM.c  
* Version 2.10
*
*  Description:
*     This file provides the power management source code to API for the
*     Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "RotaryEncoder_1_Counter.h"

static RotaryEncoder_1_Counter_backupStruct RotaryEncoder_1_Counter_backup;

/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RotaryEncoder_1_Counter_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*    No
*
*******************************************************************************/
void RotaryEncoder_1_Counter_SaveConfig(void)
{
    #if (!RotaryEncoder_1_Counter_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (RotaryEncoder_1_Counter_PSOC3_ES2 || RotaryEncoder_1_Counter_PSOC5_ES1)
            RotaryEncoder_1_Counter_backup.CounterUdb = RotaryEncoder_1_Counter_ReadCounter();
            RotaryEncoder_1_Counter_backup.CounterPeriod = RotaryEncoder_1_Counter_ReadPeriod();
            RotaryEncoder_1_Counter_backup.CompareValue = RotaryEncoder_1_Counter_ReadCompare();
            RotaryEncoder_1_Counter_backup.InterruptMaskValue = RotaryEncoder_1_Counter_STATUS_MASK;
        #endif
        
        #if (RotaryEncoder_1_Counter_PSOC3_ES3 || RotaryEncoder_1_Counter_PSOC5_ES2)
            RotaryEncoder_1_Counter_backup.CounterUdb = RotaryEncoder_1_Counter_ReadCounter();
            RotaryEncoder_1_Counter_backup.InterruptMaskValue = RotaryEncoder_1_Counter_STATUS_MASK;
        #endif
        
        #if(!RotaryEncoder_1_Counter_ControlRegRemoved)
            RotaryEncoder_1_Counter_backup.CounterControlRegister = RotaryEncoder_1_Counter_ReadControlRegister();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RotaryEncoder_1_Counter_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_RestoreConfig(void) 
{      
    #if (!RotaryEncoder_1_Counter_UsingFixedFunction)     
        /* Restore the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (RotaryEncoder_1_Counter_PSOC3_ES2 || RotaryEncoder_1_Counter_PSOC5_ES1)
            /* Interrupt State Backup for Critical Region*/
            uint8 RotaryEncoder_1_Counter_interruptState;
        
            RotaryEncoder_1_Counter_WriteCounter(RotaryEncoder_1_Counter_backup.CounterUdb);
            RotaryEncoder_1_Counter_WritePeriod(RotaryEncoder_1_Counter_backup.CounterPeriod);
            RotaryEncoder_1_Counter_WriteCompare(RotaryEncoder_1_Counter_backup.CompareValue);
            /* Enter Critical Region*/
            RotaryEncoder_1_Counter_interruptState = CyEnterCriticalSection();
        
            RotaryEncoder_1_Counter_STATUS_AUX_CTRL |= RotaryEncoder_1_Counter_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(RotaryEncoder_1_Counter_interruptState);
            RotaryEncoder_1_Counter_STATUS_MASK = RotaryEncoder_1_Counter_backup.InterruptMaskValue;
        #endif
        
        #if (RotaryEncoder_1_Counter_PSOC3_ES3 || RotaryEncoder_1_Counter_PSOC5_ES2)
            RotaryEncoder_1_Counter_WriteCounter(RotaryEncoder_1_Counter_backup.CounterUdb);
            RotaryEncoder_1_Counter_STATUS_MASK = RotaryEncoder_1_Counter_backup.InterruptMaskValue;
        #endif
        
        #if(!RotaryEncoder_1_Counter_ControlRegRemoved)
            RotaryEncoder_1_Counter_WriteControlRegister(RotaryEncoder_1_Counter_backup.CounterControlRegister);
        #endif
    #endif
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RotaryEncoder_1_Counter_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Sleep(void)
{
    #if(!RotaryEncoder_1_Counter_ControlRegRemoved)
        /* Save Counter's enable state */
        if(RotaryEncoder_1_Counter_CTRL_ENABLE == (RotaryEncoder_1_Counter_CONTROL & RotaryEncoder_1_Counter_CTRL_ENABLE))
        {
            /* Counter is enabled */
            RotaryEncoder_1_Counter_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            RotaryEncoder_1_Counter_backup.CounterEnableState = 0u;
        }
    #endif
    RotaryEncoder_1_Counter_Stop();
    RotaryEncoder_1_Counter_SaveConfig();
}


/*******************************************************************************
* Function Name: RotaryEncoder_1_Counter_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  RotaryEncoder_1_Counter_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void RotaryEncoder_1_Counter_Wakeup(void) 
{
    RotaryEncoder_1_Counter_RestoreConfig();
    #if(!RotaryEncoder_1_Counter_ControlRegRemoved)
        if(RotaryEncoder_1_Counter_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            RotaryEncoder_1_Counter_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif
    
}


/* [] END OF FILE */
