/*******************************************************************************
* File Name: SignalTime_PM.c
* Version 2.50
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "SignalTime.h"
static SignalTime_backupStruct SignalTime_backup;


/*******************************************************************************
* Function Name: SignalTime_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTime_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void SignalTime_SaveConfig(void) 
{
    #if (!SignalTime_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            SignalTime_backup.TimerUdb = SignalTime_ReadCounter();
            SignalTime_backup.TimerPeriod = SignalTime_ReadPeriod();
            SignalTime_backup.InterruptMaskValue = SignalTime_STATUS_MASK;
            #if (SignalTime_UsingHWCaptureCounter)
                SignalTime_backup.TimerCaptureCounter = SignalTime_ReadCaptureCount();
            #endif /* Backup the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Backup the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            SignalTime_backup.TimerUdb = SignalTime_ReadCounter();
            SignalTime_backup.InterruptMaskValue = SignalTime_STATUS_MASK;
            #if (SignalTime_UsingHWCaptureCounter)
                SignalTime_backup.TimerCaptureCounter = SignalTime_ReadCaptureCount();
            #endif /* Back Up capture counter register  */
        #endif /* Backup non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!SignalTime_ControlRegRemoved)
            SignalTime_backup.TimerControlRegister = SignalTime_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: SignalTime_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTime_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void SignalTime_RestoreConfig(void) 
{   
    #if (!SignalTime_UsingFixedFunction)
        /* Restore the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            /* Interrupt State Backup for Critical Region*/
            uint8 SignalTime_interruptState;

            SignalTime_WriteCounter(SignalTime_backup.TimerUdb);
            SignalTime_WritePeriod(SignalTime_backup.TimerPeriod);
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            SignalTime_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            SignalTime_STATUS_AUX_CTRL |= SignalTime_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(SignalTime_interruptState);
            SignalTime_STATUS_MASK =SignalTime_backup.InterruptMaskValue;
            #if (SignalTime_UsingHWCaptureCounter)
                SignalTime_SetCaptureCount(SignalTime_backup.TimerCaptureCounter);
            #endif /* Restore the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Restore the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            SignalTime_WriteCounter(SignalTime_backup.TimerUdb);
            SignalTime_STATUS_MASK =SignalTime_backup.InterruptMaskValue;
            #if (SignalTime_UsingHWCaptureCounter)
                SignalTime_SetCaptureCount(SignalTime_backup.TimerCaptureCounter);
            #endif /* Restore Capture counter register*/
        #endif /* Restore up non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!SignalTime_ControlRegRemoved)
            SignalTime_WriteControlRegister(SignalTime_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: SignalTime_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTime_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void SignalTime_Sleep(void) 
{
    #if(!SignalTime_ControlRegRemoved)
        /* Save Counter's enable state */
        if(SignalTime_CTRL_ENABLE == (SignalTime_CONTROL & SignalTime_CTRL_ENABLE))
        {
            /* Timer is enabled */
            SignalTime_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            SignalTime_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    SignalTime_Stop();
    SignalTime_SaveConfig();
}


/*******************************************************************************
* Function Name: SignalTime_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTime_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void SignalTime_Wakeup(void) 
{
    SignalTime_RestoreConfig();
    #if(!SignalTime_ControlRegRemoved)
        if(SignalTime_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                SignalTime_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
