/*******************************************************************************
* File Name: SignalTimer_PM.c
* Version 2.50
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "SignalTimer.h"
static SignalTimer_backupStruct SignalTimer_backup;


/*******************************************************************************
* Function Name: SignalTimer_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTimer_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void SignalTimer_SaveConfig(void) 
{
    #if (!SignalTimer_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            SignalTimer_backup.TimerUdb = SignalTimer_ReadCounter();
            SignalTimer_backup.TimerPeriod = SignalTimer_ReadPeriod();
            SignalTimer_backup.InterruptMaskValue = SignalTimer_STATUS_MASK;
            #if (SignalTimer_UsingHWCaptureCounter)
                SignalTimer_backup.TimerCaptureCounter = SignalTimer_ReadCaptureCount();
            #endif /* Backup the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Backup the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            SignalTimer_backup.TimerUdb = SignalTimer_ReadCounter();
            SignalTimer_backup.InterruptMaskValue = SignalTimer_STATUS_MASK;
            #if (SignalTimer_UsingHWCaptureCounter)
                SignalTimer_backup.TimerCaptureCounter = SignalTimer_ReadCaptureCount();
            #endif /* Back Up capture counter register  */
        #endif /* Backup non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!SignalTimer_ControlRegRemoved)
            SignalTimer_backup.TimerControlRegister = SignalTimer_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: SignalTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTimer_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void SignalTimer_RestoreConfig(void) 
{   
    #if (!SignalTimer_UsingFixedFunction)
        /* Restore the UDB non-rentention registers for CY_UDB_V0 */
        #if (CY_UDB_V0)
            /* Interrupt State Backup for Critical Region*/
            uint8 SignalTimer_interruptState;

            SignalTimer_WriteCounter(SignalTimer_backup.TimerUdb);
            SignalTimer_WritePeriod(SignalTimer_backup.TimerPeriod);
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            SignalTimer_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            SignalTimer_STATUS_AUX_CTRL |= SignalTimer_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(SignalTimer_interruptState);
            SignalTimer_STATUS_MASK =SignalTimer_backup.InterruptMaskValue;
            #if (SignalTimer_UsingHWCaptureCounter)
                SignalTimer_SetCaptureCount(SignalTimer_backup.TimerCaptureCounter);
            #endif /* Restore the UDB non-rentention register capture counter for CY_UDB_V0 */
        #endif /* Restore the UDB non-rentention registers for CY_UDB_V0 */

        #if (CY_UDB_V1)
            SignalTimer_WriteCounter(SignalTimer_backup.TimerUdb);
            SignalTimer_STATUS_MASK =SignalTimer_backup.InterruptMaskValue;
            #if (SignalTimer_UsingHWCaptureCounter)
                SignalTimer_SetCaptureCount(SignalTimer_backup.TimerCaptureCounter);
            #endif /* Restore Capture counter register*/
        #endif /* Restore up non retention registers, interrupt mask and capture counter for CY_UDB_V1 */

        #if(!SignalTimer_ControlRegRemoved)
            SignalTimer_WriteControlRegister(SignalTimer_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: SignalTimer_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTimer_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void SignalTimer_Sleep(void) 
{
    #if(!SignalTimer_ControlRegRemoved)
        /* Save Counter's enable state */
        if(SignalTimer_CTRL_ENABLE == (SignalTimer_CONTROL & SignalTimer_CTRL_ENABLE))
        {
            /* Timer is enabled */
            SignalTimer_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            SignalTimer_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    SignalTimer_Stop();
    SignalTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: SignalTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SignalTimer_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void SignalTimer_Wakeup(void) 
{
    SignalTimer_RestoreConfig();
    #if(!SignalTimer_ControlRegRemoved)
        if(SignalTimer_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                SignalTimer_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
