*******************************************************************************
* File Name: Signal_Timer.c  
* Version 2.40
*
*  Description:
*     The Counter component consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Signal_Timer.h"

uint8 Signal_Timer_initVar = 0u;


/*******************************************************************************
* Function Name: Signal_Timer_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Signal_Timer_Init(void) 
{
        #if (!Signal_Timer_UsingFixedFunction && !Signal_Timer_ControlRegRemoved)
            uint8 ctrl;
        #endif /* (!Signal_Timer_UsingFixedFunction && !Signal_Timer_ControlRegRemoved) */
        
        #if(!Signal_Timer_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 Signal_Timer_interruptState;
        #endif /* (!Signal_Timer_UsingFixedFunction) */
        
        #if (Signal_Timer_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            Signal_Timer_CONTROL &= Signal_Timer_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (CY_PSOC5A)
                Signal_Timer_CONTROL2 &= ((uint8)(~Signal_Timer_CTRL_MODE_MASK));
            #endif /* (CY_PSOC5A) */
            #if (CY_PSOC3 || CY_PSOC5LP)
                Signal_Timer_CONTROL3 &= ((uint8)(~Signal_Timer_CTRL_MODE_MASK));                
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (Signal_Timer_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                Signal_Timer_CONTROL |= Signal_Timer_ONESHOT;
            #endif /* (Signal_Timer_RunModeUsed != 0x0u) */
            
            /* Set the IRQ to use the status register interrupts */
            Signal_Timer_CONTROL2 |= Signal_Timer_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            Signal_Timer_RT1 &= ((uint8)(~Signal_Timer_RT1_MASK));
            Signal_Timer_RT1 |= Signal_Timer_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            Signal_Timer_RT1 &= ((uint8)(~Signal_Timer_SYNCDSI_MASK));
            Signal_Timer_RT1 |= Signal_Timer_SYNCDSI_EN;

        #else
            #if(!Signal_Timer_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = Signal_Timer_CONTROL & ((uint8)(~Signal_Timer_CTRL_CMPMODE_MASK));
            Signal_Timer_CONTROL = ctrl | Signal_Timer_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = Signal_Timer_CONTROL & ((uint8)(~Signal_Timer_CTRL_CAPMODE_MASK));
            
            #if( 0 != Signal_Timer_CAPTURE_MODE_CONF)
                Signal_Timer_CONTROL = ctrl | Signal_Timer_DEFAULT_CAPTURE_MODE;
            #else
                Signal_Timer_CONTROL = ctrl;
            #endif /* 0 != Signal_Timer_CAPTURE_MODE */ 
            
            #endif /* (!Signal_Timer_ControlRegRemoved) */
        #endif /* (Signal_Timer_UsingFixedFunction) */
        
        /* Clear all data in the FIFO's */
        #if (!Signal_Timer_UsingFixedFunction)
            Signal_Timer_ClearFIFO();
        #endif /* (!Signal_Timer_UsingFixedFunction) */
        
        /* Set Initial values from Configuration */
        Signal_Timer_WritePeriod(Signal_Timer_INIT_PERIOD_VALUE);
        #if (!(Signal_Timer_UsingFixedFunction && (CY_PSOC5A)))
            Signal_Timer_WriteCounter(Signal_Timer_INIT_COUNTER_VALUE);
        #endif /* (!(Signal_Timer_UsingFixedFunction && (CY_PSOC5A))) */
        Signal_Timer_SetInterruptMode(Signal_Timer_INIT_INTERRUPTS_MASK);
        
        #if (!Signal_Timer_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            (void)Signal_Timer_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            Signal_Timer_WriteCompare(Signal_Timer_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Signal_Timer_interruptState = CyEnterCriticalSection();
            
            Signal_Timer_STATUS_AUX_CTRL |= Signal_Timer_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(Signal_Timer_interruptState);
            
        #endif /* (!Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
*******************************************************************************/
void Signal_Timer_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (Signal_Timer_UsingFixedFunction)
        Signal_Timer_GLOBAL_ENABLE |= Signal_Timer_BLOCK_EN_MASK;
        Signal_Timer_GLOBAL_STBY_ENABLE |= Signal_Timer_BLOCK_STBY_EN_MASK;
    #endif /* (Signal_Timer_UsingFixedFunction) */  
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!Signal_Timer_ControlRegRemoved || Signal_Timer_UsingFixedFunction)
        Signal_Timer_CONTROL |= Signal_Timer_CTRL_ENABLE;                
    #endif /* (!Signal_Timer_ControlRegRemoved || Signal_Timer_UsingFixedFunction) */
    
}


/*******************************************************************************
* Function Name: Signal_Timer_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  Signal_Timer_initVar: Is modified when this function is called for the  
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void Signal_Timer_Start(void) 
{
    if(Signal_Timer_initVar == 0u)
    {
        Signal_Timer_Init();
        
        Signal_Timer_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    Signal_Timer_Enable();        
}


/*******************************************************************************
* Function Name: Signal_Timer_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
*******************************************************************************/
void Signal_Timer_Stop(void) 
{
    /* Disable Counter */
    #if(!Signal_Timer_ControlRegRemoved || Signal_Timer_UsingFixedFunction)
        Signal_Timer_CONTROL &= ((uint8)(~Signal_Timer_CTRL_ENABLE));        
    #endif /* (!Signal_Timer_ControlRegRemoved || Signal_Timer_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (Signal_Timer_UsingFixedFunction)
        Signal_Timer_GLOBAL_ENABLE &= ((uint8)(~Signal_Timer_BLOCK_EN_MASK));
        Signal_Timer_GLOBAL_STBY_ENABLE &= ((uint8)(~Signal_Timer_BLOCK_STBY_EN_MASK));
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
*******************************************************************************/
void Signal_Timer_SetInterruptMode(uint8 interruptsMask) 
{
    Signal_Timer_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: Signal_Timer_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
*******************************************************************************/
uint8   Signal_Timer_ReadStatusRegister(void) 
{
    return Signal_Timer_STATUS;
}


#if(!Signal_Timer_ControlRegRemoved)
/*******************************************************************************
* Function Name: Signal_Timer_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
uint8   Signal_Timer_ReadControlRegister(void) 
{
    return Signal_Timer_CONTROL;
}


/*******************************************************************************
* Function Name: Signal_Timer_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
void    Signal_Timer_WriteControlRegister(uint8 control) 
{
    Signal_Timer_CONTROL = control;
}

#endif  /* (!Signal_Timer_ControlRegRemoved) */


#if (!(Signal_Timer_UsingFixedFunction && (CY_PSOC5A)))
/*******************************************************************************
* Function Name: Signal_Timer_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
*******************************************************************************/
void Signal_Timer_WriteCounter(uint8 counter) \
                                   
{
    #if(Signal_Timer_UsingFixedFunction)
        /* assert if block is already enabled */
        CYASSERT (0u == (Signal_Timer_GLOBAL_ENABLE & Signal_Timer_BLOCK_EN_MASK));
        /* If block is disabled, enable it and then write the counter */
        Signal_Timer_GLOBAL_ENABLE |= Signal_Timer_BLOCK_EN_MASK;
        CY_SET_REG16(Signal_Timer_COUNTER_LSB_PTR, (uint16)counter);
        Signal_Timer_GLOBAL_ENABLE &= ((uint8)(~Signal_Timer_BLOCK_EN_MASK));
    #else
        CY_SET_REG8(Signal_Timer_COUNTER_LSB_PTR, counter);
    #endif /* (Signal_Timer_UsingFixedFunction) */
}
#endif /* (!(Signal_Timer_UsingFixedFunction && (CY_PSOC5A))) */


/*******************************************************************************
* Function Name: Signal_Timer_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) The present value of the counter.
*
*******************************************************************************/
uint8 Signal_Timer_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    #if(Signal_Timer_UsingFixedFunction)
		(void)CY_GET_REG16(Signal_Timer_COUNTER_LSB_PTR);
	#else
		(void)CY_GET_REG8(Signal_Timer_COUNTER_LSB_PTR_8BIT);
	#endif/* (Signal_Timer_UsingFixedFunction) */
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    #if(Signal_Timer_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(Signal_Timer_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(Signal_Timer_STATICCOUNT_LSB_PTR));
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) Present Capture value.
*
*******************************************************************************/
uint8 Signal_Timer_ReadCapture(void) 
{
    #if(Signal_Timer_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(Signal_Timer_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(Signal_Timer_STATICCOUNT_LSB_PTR));
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint8) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
*******************************************************************************/
void Signal_Timer_WritePeriod(uint8 period) 
{
    #if(Signal_Timer_UsingFixedFunction)
        CY_SET_REG16(Signal_Timer_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG8(Signal_Timer_PERIOD_LSB_PTR, period);
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) Present period value.
*
*******************************************************************************/
uint8 Signal_Timer_ReadPeriod(void) 
{
    #if(Signal_Timer_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(Signal_Timer_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(Signal_Timer_PERIOD_LSB_PTR));
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


#if (!Signal_Timer_UsingFixedFunction)
/*******************************************************************************
* Function Name: Signal_Timer_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
*******************************************************************************/
void Signal_Timer_WriteCompare(uint8 compare) \
                                   
{
    #if(Signal_Timer_UsingFixedFunction)
        CY_SET_REG16(Signal_Timer_COMPARE_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG8(Signal_Timer_COMPARE_LSB_PTR, compare);
    #endif /* (Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint8) Present compare value.
*
*******************************************************************************/
uint8 Signal_Timer_ReadCompare(void) 
{
    return (CY_GET_REG8(Signal_Timer_COMPARE_LSB_PTR));
}


#if (Signal_Timer_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: Signal_Timer_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void Signal_Timer_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    Signal_Timer_CONTROL &= ((uint8)(~Signal_Timer_CTRL_CMPMODE_MASK));
    
    /* Write the new setting */
    Signal_Timer_CONTROL |= compareMode;
}
#endif  /* (Signal_Timer_COMPARE_MODE_SOFTWARE) */


#if (Signal_Timer_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: Signal_Timer_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void Signal_Timer_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    Signal_Timer_CONTROL &= ((uint8)(~Signal_Timer_CTRL_CAPMODE_MASK));
    
    /* Write the new setting */
    Signal_Timer_CONTROL |= ((uint8)((uint8)captureMode << Signal_Timer_CTRL_CAPMODE0_SHIFT));
}
#endif  /* (Signal_Timer_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: Signal_Timer_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
*******************************************************************************/
void Signal_Timer_ClearFIFO(void) 
{

    while(0u != (Signal_Timer_ReadStatusRegister() & Signal_Timer_STATUS_FIFONEMP))
    {
        (void)Signal_Timer_ReadCapture();
    }

}
#endif  /* (!Signal_Timer_UsingFixedFunction) */


/* [] END OF FILE */

