/*******************************************************************************
* File Name: Signal_Timer_PM.c  
* Version 2.40
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Signal_Timer.h"

static Signal_Timer_backupStruct Signal_Timer_backup;


/*******************************************************************************
* Function Name: Signal_Timer_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Signal_Timer_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void Signal_Timer_SaveConfig(void) 
{
    #if (!Signal_Timer_UsingFixedFunction)

        Signal_Timer_backup.CounterUdb = Signal_Timer_ReadCounter();

        #if (CY_UDB_V0)
            Signal_Timer_backup.CounterPeriod = Signal_Timer_ReadPeriod();
            Signal_Timer_backup.CompareValue = Signal_Timer_ReadCompare();
            Signal_Timer_backup.InterruptMaskValue = Signal_Timer_STATUS_MASK;
        #endif /* CY_UDB_V0 */

        #if(!Signal_Timer_ControlRegRemoved)
            Signal_Timer_backup.CounterControlRegister = Signal_Timer_ReadControlRegister();
        #endif /* (!Signal_Timer_ControlRegRemoved) */

    #endif /* (!Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Signal_Timer_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Signal_Timer_RestoreConfig(void) 
{      
    #if (!Signal_Timer_UsingFixedFunction)

        #if (CY_UDB_V0)
            uint8 Signal_Timer_interruptState;
        #endif  /* (CY_UDB_V0) */

       Signal_Timer_WriteCounter(Signal_Timer_backup.CounterUdb);

        #if (CY_UDB_V0)
            Signal_Timer_WritePeriod(Signal_Timer_backup.CounterPeriod);
            Signal_Timer_WriteCompare(Signal_Timer_backup.CompareValue);

            Signal_Timer_interruptState = CyEnterCriticalSection();
            Signal_Timer_STATUS_AUX_CTRL |= Signal_Timer_STATUS_ACTL_INT_EN_MASK;
            CyExitCriticalSection(Signal_Timer_interruptState);

            Signal_Timer_STATUS_MASK = Signal_Timer_backup.InterruptMaskValue;
        #endif  /* (CY_UDB_V0) */

        #if(!Signal_Timer_ControlRegRemoved)
            Signal_Timer_WriteControlRegister(Signal_Timer_backup.CounterControlRegister);
        #endif /* (!Signal_Timer_ControlRegRemoved) */

    #endif /* (!Signal_Timer_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Signal_Timer_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Signal_Timer_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void Signal_Timer_Sleep(void) 
{
    #if(!Signal_Timer_ControlRegRemoved)
        /* Save Counter's enable state */
        if(Signal_Timer_CTRL_ENABLE == (Signal_Timer_CONTROL & Signal_Timer_CTRL_ENABLE))
        {
            /* Counter is enabled */
            Signal_Timer_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            Signal_Timer_backup.CounterEnableState = 0u;
        }
    #else
        Signal_Timer_backup.CounterEnableState = 1u;
        if(Signal_Timer_backup.CounterEnableState != 0u)
        {
            Signal_Timer_backup.CounterEnableState = 0u;
        }
    #endif /* (!Signal_Timer_ControlRegRemoved) */
    
    Signal_Timer_Stop();
    Signal_Timer_SaveConfig();
}


/*******************************************************************************
* Function Name: Signal_Timer_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Signal_Timer_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Signal_Timer_Wakeup(void) 
{
    Signal_Timer_RestoreConfig();
    #if(!Signal_Timer_ControlRegRemoved)
        if(Signal_Timer_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            Signal_Timer_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!Signal_Timer_ControlRegRemoved) */
    
}


/* [] END OF FILE */
