/*******************************************************************************
* File Name: Xdac.c  
* Version 1.80
*
* Description:
*  This file provides the source code to the API for the 8-bit Voltage DAC 
*  (VDAC8) User Module.
*
* Note:
*  Any unusual or non-standard behavior should be noted here. Other-
*  wise, this section should remain blank.
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Xdac.h"

#if (CY_PSOC5A)
#include <CyLib.h>
#endif /* CY_PSOC5A */

uint8 Xdac_initVar = 0;

#if (CY_PSOC5A)
    uint8 Xdac_restoreVal = 0;
    uint8 Xdac_intrStatus = 0u;
#endif /* CY_PSOC5A */

#if (CY_PSOC5A)
    static Xdac_backupStruct Xdac_backup;
#endif /* CY_PSOC5A */


/*******************************************************************************
* Function Name: Xdac_Init
********************************************************************************
* Summary:
*  Initialize to the schematic state.
* 
* Parameters:
*  void:
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Xdac_Init(void) 
{
    Xdac_CR0 = (Xdac_MODE_V );

    /* Set default data source */
    if(Xdac_DEFAULT_DATA_SRC != 0 )
    {
        Xdac_CR1 = (Xdac_DEFAULT_CNTL | Xdac_DACBUS_ENABLE) ;
    }
    else
    {
        Xdac_CR1 = (Xdac_DEFAULT_CNTL | Xdac_DACBUS_DISABLE) ;
    }

    /* Set default strobe mode */
    if(Xdac_DEFAULT_STRB != 0)
    {
        Xdac_Strobe |= Xdac_STRB_EN ;
    }

    /* Set default range */
    Xdac_SetRange(Xdac_DEFAULT_RANGE); 

    /* Set default speed */
    Xdac_SetSpeed(Xdac_DEFAULT_SPEED);
}


/*******************************************************************************
* Function Name: Xdac_Enable
********************************************************************************
* Summary:
*  Enable the VDAC8
* 
* Parameters:
*  void
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Xdac_Enable(void) 
{
    Xdac_PWRMGR |= Xdac_ACT_PWR_EN;
    Xdac_STBY_PWRMGR |= Xdac_STBY_PWR_EN;

    /*This is to restore the value of register CR0 ,
    which is modified  in Stop API , this prevents misbehaviour of VDAC */
    #if (CY_PSOC5A)
        if(Xdac_restoreVal == 1) 
        {
             Xdac_CR0 = Xdac_backup.data_value;
             Xdac_restoreVal = 0;
        }
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Xdac_Start
********************************************************************************
*
* Summary:
*  The start function initializes the voltage DAC with the default values, 
*  and sets the power to the given level.  A power level of 0, is the same as
*  executing the stop function.
*
* Parameters:
*  Power: Sets power level between off (0) and (3) high power
*
* Return:
*  void 
*
* Global variables:
*  Xdac_initVar: Is modified when this function is called for the 
*  first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void Xdac_Start(void)  
{
    /* Hardware initiazation only needs to occure the first time */
    if(Xdac_initVar == 0)
    { 
        Xdac_Init();
        Xdac_initVar = 1;
    }

    /* Enable power to DAC */
    Xdac_Enable();

    /* Set default value */
    Xdac_SetValue(Xdac_DEFAULT_DATA); 
}


/*******************************************************************************
* Function Name: Xdac_Stop
********************************************************************************
*
* Summary:
*  Powers down DAC to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Xdac_Stop(void) 
{
    /* Disble power to DAC */
    Xdac_PWRMGR &= ~Xdac_ACT_PWR_EN;
    Xdac_STBY_PWRMGR &= ~Xdac_STBY_PWR_EN;

    /* This is a work around for PSoC5A  ,
    this sets VDAC to current mode with output off */
    #if (CY_PSOC5A)
        Xdac_backup.data_value = Xdac_CR0;
        Xdac_CR0 = Xdac_CUR_MODE_OUT_OFF;
        Xdac_restoreVal = 1;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Xdac_SetSpeed
********************************************************************************
*
* Summary:
*  Set DAC speed
*
* Parameters:
*  power: Sets speed value
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Xdac_SetSpeed(uint8 speed) 
{
    /* Clear power mask then write in new value */
    Xdac_CR0 &= ~Xdac_HS_MASK ;
    Xdac_CR0 |=  ( speed & Xdac_HS_MASK) ;
}


/*******************************************************************************
* Function Name: Xdac_SetRange
********************************************************************************
*
* Summary:
*  Set one of three current ranges.
*
* Parameters:
*  Range: Sets one of Three valid ranges.
*
* Return:
*  void 
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Xdac_SetRange(uint8 range) 
{
    Xdac_CR0 &= ~Xdac_RANGE_MASK ;      /* Clear existing mode */
    Xdac_CR0 |= ( range & Xdac_RANGE_MASK ) ; /*  Set Range  */
    Xdac_DacTrim();
}


/*******************************************************************************
* Function Name: Xdac_SetValue
********************************************************************************
*
* Summary:
*  Set 8-bit DAC value
*
* Parameters:  
*  value:  Sets DAC value between 0 and 255.
*
* Return: 
*  void 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Xdac_SetValue(uint8 value) 
{
    #if (CY_PSOC5A)
        Xdac_intrStatus = CyEnterCriticalSection();
    #endif /* CY_PSOC5A */

    Xdac_Data = value;                /*  Set Value  */

    /* PSOC5A requires a double write */
    /* Exit Critical Section */
    #if (CY_PSOC5A)
        Xdac_Data = value;
        CyExitCriticalSection(Xdac_intrStatus);
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Xdac_DacTrim
********************************************************************************
*
* Summary:
*  Set the trim value for the given range.
*
* Parameters:
*  range:  1V or 4V range.  See constants.
*
* Return:
*  void
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Xdac_DacTrim(void) 
{
    uint8 mode;

    mode = ((Xdac_CR0 & Xdac_RANGE_MASK) >> 2) + Xdac_TRIM_M7_1V_RNG_OFFSET;
    Xdac_TR = CY_GET_XTND_REG8((uint8 *)(Xdac_DAC_TRIM_BASE + mode));
}


/* [] END OF FILE */
