/*******************************************************************************
* File Name: Ydac.c  
* Version 1.80
*
* Description:
*  This file provides the source code to the API for the 8-bit Voltage DAC 
*  (VDAC8) User Module.
*
* Note:
*  Any unusual or non-standard behavior should be noted here. Other-
*  wise, this section should remain blank.
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Ydac.h"

#if (CY_PSOC5A)
#include <CyLib.h>
#endif /* CY_PSOC5A */

uint8 Ydac_initVar = 0;

#if (CY_PSOC5A)
    uint8 Ydac_restoreVal = 0;
    uint8 Ydac_intrStatus = 0u;
#endif /* CY_PSOC5A */

#if (CY_PSOC5A)
    static Ydac_backupStruct Ydac_backup;
#endif /* CY_PSOC5A */


/*******************************************************************************
* Function Name: Ydac_Init
********************************************************************************
* Summary:
*  Initialize to the schematic state.
* 
* Parameters:
*  void:
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Ydac_Init(void) 
{
    Ydac_CR0 = (Ydac_MODE_V );

    /* Set default data source */
    if(Ydac_DEFAULT_DATA_SRC != 0 )
    {
        Ydac_CR1 = (Ydac_DEFAULT_CNTL | Ydac_DACBUS_ENABLE) ;
    }
    else
    {
        Ydac_CR1 = (Ydac_DEFAULT_CNTL | Ydac_DACBUS_DISABLE) ;
    }

    /* Set default strobe mode */
    if(Ydac_DEFAULT_STRB != 0)
    {
        Ydac_Strobe |= Ydac_STRB_EN ;
    }

    /* Set default range */
    Ydac_SetRange(Ydac_DEFAULT_RANGE); 

    /* Set default speed */
    Ydac_SetSpeed(Ydac_DEFAULT_SPEED);
}


/*******************************************************************************
* Function Name: Ydac_Enable
********************************************************************************
* Summary:
*  Enable the VDAC8
* 
* Parameters:
*  void
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Ydac_Enable(void) 
{
    Ydac_PWRMGR |= Ydac_ACT_PWR_EN;
    Ydac_STBY_PWRMGR |= Ydac_STBY_PWR_EN;

    /*This is to restore the value of register CR0 ,
    which is modified  in Stop API , this prevents misbehaviour of VDAC */
    #if (CY_PSOC5A)
        if(Ydac_restoreVal == 1) 
        {
             Ydac_CR0 = Ydac_backup.data_value;
             Ydac_restoreVal = 0;
        }
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Ydac_Start
********************************************************************************
*
* Summary:
*  The start function initializes the voltage DAC with the default values, 
*  and sets the power to the given level.  A power level of 0, is the same as
*  executing the stop function.
*
* Parameters:
*  Power: Sets power level between off (0) and (3) high power
*
* Return:
*  void 
*
* Global variables:
*  Ydac_initVar: Is modified when this function is called for the 
*  first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void Ydac_Start(void)  
{
    /* Hardware initiazation only needs to occure the first time */
    if(Ydac_initVar == 0)
    { 
        Ydac_Init();
        Ydac_initVar = 1;
    }

    /* Enable power to DAC */
    Ydac_Enable();

    /* Set default value */
    Ydac_SetValue(Ydac_DEFAULT_DATA); 
}


/*******************************************************************************
* Function Name: Ydac_Stop
********************************************************************************
*
* Summary:
*  Powers down DAC to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Ydac_Stop(void) 
{
    /* Disble power to DAC */
    Ydac_PWRMGR &= ~Ydac_ACT_PWR_EN;
    Ydac_STBY_PWRMGR &= ~Ydac_STBY_PWR_EN;

    /* This is a work around for PSoC5A  ,
    this sets VDAC to current mode with output off */
    #if (CY_PSOC5A)
        Ydac_backup.data_value = Ydac_CR0;
        Ydac_CR0 = Ydac_CUR_MODE_OUT_OFF;
        Ydac_restoreVal = 1;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Ydac_SetSpeed
********************************************************************************
*
* Summary:
*  Set DAC speed
*
* Parameters:
*  power: Sets speed value
*
* Return:
*  void
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Ydac_SetSpeed(uint8 speed) 
{
    /* Clear power mask then write in new value */
    Ydac_CR0 &= ~Ydac_HS_MASK ;
    Ydac_CR0 |=  ( speed & Ydac_HS_MASK) ;
}


/*******************************************************************************
* Function Name: Ydac_SetRange
********************************************************************************
*
* Summary:
*  Set one of three current ranges.
*
* Parameters:
*  Range: Sets one of Three valid ranges.
*
* Return:
*  void 
*
* Theory:
*
* Side Effects:
*
*******************************************************************************/
void Ydac_SetRange(uint8 range) 
{
    Ydac_CR0 &= ~Ydac_RANGE_MASK ;      /* Clear existing mode */
    Ydac_CR0 |= ( range & Ydac_RANGE_MASK ) ; /*  Set Range  */
    Ydac_DacTrim();
}


/*******************************************************************************
* Function Name: Ydac_SetValue
********************************************************************************
*
* Summary:
*  Set 8-bit DAC value
*
* Parameters:  
*  value:  Sets DAC value between 0 and 255.
*
* Return: 
*  void 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Ydac_SetValue(uint8 value) 
{
    #if (CY_PSOC5A)
        Ydac_intrStatus = CyEnterCriticalSection();
    #endif /* CY_PSOC5A */

    Ydac_Data = value;                /*  Set Value  */

    /* PSOC5A requires a double write */
    /* Exit Critical Section */
    #if (CY_PSOC5A)
        Ydac_Data = value;
        CyExitCriticalSection(Ydac_intrStatus);
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: Ydac_DacTrim
********************************************************************************
*
* Summary:
*  Set the trim value for the given range.
*
* Parameters:
*  range:  1V or 4V range.  See constants.
*
* Return:
*  void
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Ydac_DacTrim(void) 
{
    uint8 mode;

    mode = ((Ydac_CR0 & Ydac_RANGE_MASK) >> 2) + Ydac_TRIM_M7_1V_RNG_OFFSET;
    Ydac_TR = CY_GET_XTND_REG8((uint8 *)(Ydac_DAC_TRIM_BASE + mode));
}


/* [] END OF FILE */
