/*******************************************************************************
* File Name: Ydac.h  
* Version 1.80
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Voltage DAC (vDAC8) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_VDAC8_Ydac_H) 
#define CY_VDAC8_Ydac_H

#include "cytypes.h"
#include "cyfitter.h"

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component VDAC8_v1_80 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct Ydac_backupStruct
{
    uint8 enableState; 
    uint8 data_value;
}Ydac_backupStruct;


/***************************************
*        Function Prototypes 
***************************************/

void Ydac_Start(void)           ;
void Ydac_Stop(void)            ;
void Ydac_SetSpeed(uint8 speed) ;
void Ydac_SetRange(uint8 range) ;
void Ydac_SetValue(uint8 value) ;
void Ydac_DacTrim(void)         ;
void Ydac_Init(void)            ;
void Ydac_Enable(void)          ;
void Ydac_SaveConfig(void)      ;
void Ydac_RestoreConfig(void)   ;
void Ydac_Sleep(void)           ;
void Ydac_Wakeup(void)          ;


/***************************************
*            API Constants
***************************************/

/* SetRange constants */

#define Ydac_RANGE_1V       0x00u
#define Ydac_RANGE_4V       0x04u


/* Power setting for Start API  */
#define Ydac_LOWSPEED       0x00u
#define Ydac_HIGHSPEED      0x02u


/***************************************
*  Initialization Parameter Constants
***************************************/

 /* Default DAC range */
#define Ydac_DEFAULT_RANGE    4u
 /* Default DAC speed */
#define Ydac_DEFAULT_SPEED    2u
 /* Default Control */
#define Ydac_DEFAULT_CNTL      0x00u
/* Default Strobe mode */
#define Ydac_DEFAULT_STRB     0u
 /* Initial DAC value */
#define Ydac_DEFAULT_DATA     0u
 /* Default Data Source */
#define Ydac_DEFAULT_DATA_SRC 0u


/***************************************
*              Registers        
***************************************/

#define Ydac_CR0         (* (reg8 *) Ydac_viDAC8__CR0 )
#define Ydac_CR1         (* (reg8 *) Ydac_viDAC8__CR1 )
#define Ydac_Data        (* (reg8 *) Ydac_viDAC8__D )
#define Ydac_Data_PTR    (  (reg8 *) Ydac_viDAC8__D )
#define Ydac_Strobe      (* (reg8 *) Ydac_viDAC8__STROBE )
#define Ydac_SW0         (* (reg8 *) Ydac_viDAC8__SW0 )
#define Ydac_SW2         (* (reg8 *) Ydac_viDAC8__SW2 )
#define Ydac_SW3         (* (reg8 *) Ydac_viDAC8__SW3 )
#define Ydac_SW4         (* (reg8 *) Ydac_viDAC8__SW4 )
#define Ydac_TR          (* (reg8 *) Ydac_viDAC8__TR )
/* Power manager */
#define Ydac_PWRMGR      (* (reg8 *) Ydac_viDAC8__PM_ACT_CFG )
  /* Standby Power manager */
#define Ydac_STBY_PWRMGR (* (reg8 *) Ydac_viDAC8__PM_STBY_CFG )


/***************************************
*         Register Constants       
***************************************/

/* CR0 vDac Control Register 0 definitions */

/* Bit Field  DAC_HS_MODE                  */
#define Ydac_HS_MASK        0x02u
#define Ydac_HS_LOWPOWER    0x00u
#define Ydac_HS_HIGHSPEED   0x02u

/* Bit Field  DAC_MODE                  */
#define Ydac_MODE_MASK      0x10u
#define Ydac_MODE_V         0x00u
#define Ydac_MODE_I         0x10u

/* Bit Field  DAC_RANGE                  */
#define Ydac_RANGE_MASK     0x0Cu
#define Ydac_RANGE_0        0x00u
#define Ydac_RANGE_1        0x04u

/* CR1 iDac Control Register 1 definitions */

/* Bit Field  DAC_MX_DATA                  */
#define Ydac_SRC_MASK       0x20u
#define Ydac_SRC_REG        0x00u
#define Ydac_SRC_UDB        0x20u

/* This bit enable reset from UDB array      */
#define Ydac_RESET_MASK     0x10u
#define Ydac_RESET_ENABLE   0x10u
#define Ydac_RESET_DISABLE  0x00u

/* This bit enables data from DAC bus      */
#define Ydac_DACBUS_MASK     0x20u
#define Ydac_DACBUS_ENABLE   0x20u
#define Ydac_DACBUS_DISABLE  0x00u

/* DAC STROBE Strobe Control Register definitions */

/* Bit Field  DAC_MX_STROBE                  */
#define Ydac_STRB_MASK     0x08u
#define Ydac_STRB_EN       0x08u
#define Ydac_STRB_DIS      0x00u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define Ydac_ACT_PWR_EN   Ydac_viDAC8__PM_ACT_MSK
  /* Standby Power enable mask */
#define Ydac_STBY_PWR_EN  Ydac_viDAC8__PM_STBY_MSK


/*******************************************************************************
*              Trim    
* Note - VDAC trim values are stored in the "Customer Table" area in * Row 1 of
*the Hidden Flash.  There are 8 bytes of trim data for each VDAC block.
* The values are:
*       I Gain offset, min range, Sourcing
*       I Gain offset, min range, Sinking
*       I Gain offset, med range, Sourcing
*       I Gain offset, med range, Sinking
*       I Gain offset, max range, Sourcing
*       I Gain offset, max range, Sinking
*       V Gain offset, 1V range
*       V Gain offset, 4V range
*
* The data set for the 4 VDACs are arranged using a left side/right side
* approach:
*   Left 0, Left 1, Right 0, Right 1.
* When mapped to the VDAC0 thru VDAC3 as:
*   VDAC 0, VDAC 2, VDAC 1, VDAC 3
*******************************************************************************/
#define Ydac_TRIM_M7_1V_RNG_OFFSET  0x06u
#define Ydac_TRIM_M8_4V_RNG_OFFSET  0x07u
/*Constatnt to set DAC in current mode and turnoff output */
#define Ydac_CUR_MODE_OUT_OFF       0x1Eu 
#define Ydac_DAC_TRIM_BASE     (Ydac_viDAC8__TRIM__M1)

#endif /* CY_VDAC8_Ydac_H  */


/* [] END OF FILE */


